%Vector_Stats_CntlG.m  

% Copyright C 2004  Thomas A. Jones.  All rights reserved.
% Everyone is granted permission to copy, modify, and redistribute
% this program, but under the condition that this copyright notice
% remain intact and the Computers & Geosciences source be referenced. 
% This software has been tested extensively, but is distributed 
% WITHOUT ANY WARRANTY.  The author does not accept responsibility
% for any possible consequences of using it.

% GUI that obtains the controls that specify/define dataset to be used 

% Variables to be obtained and defaults:
%   NSkipHdr=0: Number of headers on data file to be skipped
%   NCols=0: Number of columns in data file
%   NColAz=0: Which column in data file/set contains Azimuths
%   NColFrq=0: Which column in data file/set contains Class Freqs 
%   WrOut = 1: Write results to external file (1=No, 0=Yes)
%   DegRad: Input azimuths in degrees (0) or radians (1)
%   Data_Array='': Name of array that contains data (degrees)
%   RtrnCode = 0: Error return

% Set up the figure

Hfig_GUI = figure;       % Handle to figure window

set(Hfig_GUI, 'NumberTitle', 'off', ...
    'Name','Specify dataset controls', ...
    'Menubar','none', ...
    'Units','inches',  ...
    'Position', [0.3, 2.5, 5, 4.5]);

% Set up the entries

if datatype == 1

HL_1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 27, 50, 2], ...
    'String','Number of header records to skip');
HT_1 = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 27, 8, 2], ...
    'String',num2str(NSkipHdr), ...
    'Callback','NSkipHdr = str2num(get(HT_1,''String''));');


HL_NC = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 24, 50, 2], ...
    'String','Number of columns in file');
HT_NC = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 24, 8, 2], ...
    'String',num2str(NCols), ...
    'Callback','NCols = str2num(get(HT_NC,''String''));');

else
    
HL_DAr = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 27, 60, 2], ...
    'String','Specify name of data array to be used');
HT_DAr = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 27, 15, 2], ...
    'String', Data_Array, ...
    'Callback','Data_Array = get(HT_DAr,''String'');');
    
end

HL_NCAZ = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 19, 50, 2], ...
    'String','Column number of Azimuths in file');
HT_NCAZ = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 19, 8, 2], ...
    'String',num2str(NColAz), ...
    'Callback','NColAz = str2num(get(HT_NCAZ,''String''));');

HL_NCFQ1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 16, 52, 2], ...
    'String','Column number of Class Frequencies in file');
HL_NCFQ2 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 15, 52, 2], ...
    'String',' (Enter 0 if no Count Frequency data used)');
HT_NCFQ = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 16, 8, 2], ...
    'String',num2str(NColFrq), ...
    'Callback','NColFrq = str2num(get(HT_NCFQ,''String''));');

HL_DR1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 11, 45, 2], ...
    'String','Input data in Degrees or Radians?');
HT_DR2 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[54, 11, 10, 2], ...
    'String', 'DEGR.', ...
    'Callback','DegRad = str2num(''0'');');
HT_DR3 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[69, 11, 10, 2], ...
    'String', 'Rad.', ...
    'Callback','DegRad = str2num(''1'');');

HL_OFIL1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 8, 40, 2], ...
    'String','Write calculations to output file?');
HT_OFIL2 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[55, 8, 9, 2], ...
    'String', 'Yes', ...
    'Callback','WrOut = str2num(''0'');');
HT_OFIL3 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 8, 9, 2], ...
    'String', 'NO', ...
    'Callback','WrOut = str2num(''1'');');

HPushCls = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 3, 10, 2], ...
    'String','OK', ...
    'Callback','RtrnCode = str2num(''0'');close');
HPushCncl = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 3, 10, 2], ...
    'String','Cancel', ...
    'Callback','RtrnCode = str2num(''8'');close');

uiwait





