%Vector_Stats_InitEstsMixG.m 

% Copyright C 2004  Thomas A. Jones.  All rights reserved.
% Everyone is granted permission to copy, modify, and redistribute
% this program, but under the condition that this copyright notice
% remain intact and the Computers & Geosciences source be referenced. 
% This software has been tested extensively, but is distributed 
% WITHOUT ANY WARRANTY.  The author does not accept responsibility
% for any possible consequences of using it.

% GUI that obtains the initial estimates for separating
% components of a mixture

% Variables to be obtained and defaults:
%   InitMean1: Initial estimate of vector mean, component 1
%   InitKappa1: Initial estimate of Kappa, component 1
%   InitMean2: Initial estimate of vector mean, component 2
%   InitKappa2: Initial estimate of Kappa, component 2
%   Propor1=0.5: Initial estimate of proportion of component 1
%   MaxItr: maximum number iterations
%   TolerX: tolerance for iterations
%   RtrnCode=0: Error return

% Set up the figure

Hfig_GUI = figure;       % Handle to figure window

set(Hfig_GUI, 'NumberTitle', 'off', ...
    'Name','Initial estimates of mixture', ...
    'Menubar','none', ...
    'Units','inches',  ...
    'Position', [0.3, 2.0, 5, 4]);

% Set up the entries

HC_1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 27, 65, 2], ...
    'String','Specify initial estimates for components of a mixture');

HC_MN1A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 23, 65, 2], ...
    'String','Vector mean (Theta, deg.), component 1');
HC_MN1B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[80, 23, 8, 2], ...
    'String',num2str(InitMean1), ...
    'Callback','InitMean1 = str2num(get(HC_MN1B,''String''));');

HC_KP1A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 20, 65, 2], ...
    'String','Concentration (Kappa), component 1');
HC_KP1B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[80, 20, 8, 2], ...
    'String',num2str(InitKappa1), ...
    'Callback','InitKappa1 = str2num(get(HC_KP1B,''String''));'); 

HC_MN2A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 17, 65, 2], ...
    'String','Vector mean (Theta, deg.), component 2');
HC_MN2B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[80, 17, 8, 2], ...
    'String',num2str(InitMean2), ...
    'Callback','InitMean2 = str2num(get(HC_MN2B,''String''));');

HC_KP2A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 14, 65, 2], ...
    'String','Concentration (Kappa), component 2 ');
HC_KP2B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[80, 14, 8, 2], ...
    'String',num2str(InitKappa2), ...
    'Callback','InitKappa2 = str2num(get(HC_KP2B,''String''));'); 

HC_ALF1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 11, 65, 2], ...
    'String','Proportion of component 1 in mixture');
HC_ALF2 = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[80, 11, 8, 2], ...
    'String',num2str(Propor1), ...
    'Callback','Propor1 = str2num(get(HC_ALF2,''String''));'); 

HC_MIT1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 8, 65, 2], ...
    'String','Maximum number iterations');
HC_MIT2 = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[80, 8, 8, 2], ...
    'String',num2str(MaxItr), ...
    'Callback','MaxItr = str2num(get(HC_MIT2,''String''));'); 

HC_TOL1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 5, 65, 2], ...
    'String','Tolerance to stop iterating');
HC_TOL2 = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[77, 5, 11, 2], ...
    'String',num2str(TolerX), ...
    'Callback','TolerX = str2num(get(HC_TOL2,''String''));'); 

HPushCls = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 1, 10, 2], ...
    'String','OK', ...
    'Callback','RtrnCode = str2num(''0'');close');

HPushCncl = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[80, 1, 10, 2], ...
    'String','Cancel', ...
    'Callback','RtrnCode = str2num(''10'');close');

uiwait





