%Vector_Stats_RoseCtl.m  

% Copyright C 2005  Thomas A. Jones.  All rights reserved.
% Everyone is granted permission to copy, modify, and redistribute
% this program, but under the condition that this copyright notice
% remain intact and the Computers & Geosciences source be referenced. 
% This software has been tested extensively, but is distributed 
% WITHOUT ANY WARRANTY.  The author does not accept responsibility
% for any possible consequences of using it.

% GUI that obtains the controls that specify/define rose diagram 

% Variables to be obtained and defaults:
%   NClasses: Number of classes in rose (4 - 36)    (12)
%   AzOrigin:  Origin of first class (0 - 360)      (0)
%   LinSq: Linear freq plot (0) or square-root(freq)(1)  
%   RtrnCode = 0: Error return

% Set up the figure

HRose_GUI = figure;       % Handle to figure window

set(HRose_GUI, 'NumberTitle', 'off', ...
    'Name','Rose diagram controls', ...
    'Menubar','none', ...
    'Units','inches',  ...
    'Position', [0.3, 2.5, 5, 3.3]);

% Set up the entries

HNCL_1 = uicontrol(HRose_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 18, 50, 2], ...
    'String','Number of classes in rose');
HNCL_2 = uicontrol(HRose_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 18, 8, 2], ...
    'String',num2str(NClasses), ...
    'Callback','NClasses = str2num(get(HNCL_2,''String''));');

HLAZ_1 = uicontrol(HRose_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 15, 50, 2], ...
    'String','Origin of azimuths');
HTAZ_2 = uicontrol(HRose_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 15, 8, 2], ...
    'String',num2str(AzOrigin), ...
    'Callback','AzOrigin = str2num(get(HTAZ_2,''String''));');

HLSQ_1 = uicontrol(HRose_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 12, 45, 2], ...
    'String','Plot Frequency or square-root(Freq.)?');
HTSQ_2 = uicontrol(HRose_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[56, 12, 10, 2], ...
    'String', 'FREQ', ...
    'Callback','LinSq = str2num(''0'');');
HTSQ_3 = uicontrol(HRose_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[69, 12, 12, 2], ...
    'String', 'Sq.Root', ...
    'Callback','LinSq = str2num(''1'');');

HPushClsR = uicontrol(HRose_GUI, 'Style','push', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 5, 10, 2], ...
    'String','OK', ...
    'Callback','RtrnCode = str2num(''0'');close');
HPushCnclR = uicontrol(HRose_GUI, 'Style','push', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 5, 10, 2], ...
    'String','Cancel', ...
    'Callback','RtrnCode = str2num(''8'');close');

uiwait





